@@ -20,7 +20,7 @@ from pkg_resources import resource_filename, get_distribution, \
 import subprocess
 import logging
 from ..lib import MainManager, Conflict, ConfigManager, \
-    StormManager
+    StormManager, IcepapsManager
 from .icepap_treemodel import IcepapTreeModel
 from .pageipapdriver import PageiPapDriver
 from .pageipapcrate import PageiPapCrate
@@ -40,8 +40,9 @@ from .messagedialogs import MessageDialogs
 from .templatescatalogwidget import TemplatesCatalogWidget
 from ..helpers import loggingInfo
 from ..gui.ldap.login import DialogLdapLogin
+from icepap import IcePAPController
 
-__version__ = '3.2.2'
+__version__ = '3.4.1'
 
 
 class IcepapApp(QtWidgets.QApplication):
@@ -80,8 +81,13 @@ class IcepapCMS(QtWidgets.QMainWindow):
         self._config.username = default_user
         if os.name == 'posix':  # this works for linux and macOSX
             self._config.username = os.getenv('USER', default_user)
+            self._os_nt = False
         elif os.name == 'nt':  # win NT, XP... (and Vista?)
             self._config.username = os.getenv('USERNAME', default_user)
+            self._os_nt = True
+
+        if self._os_nt:
+            self.actionConsole.setDisabled(True)
 
         if self._config.config['ldap']['use']:
             # FORCE AN LDAP LOGIN TO GET CORRECT USER NAMES IN THE DRIVER
@@ -106,6 +112,8 @@ class IcepapCMS(QtWidgets.QMainWindow):
         self.refreshTimer = Qt.QTimer(self)
         self.checkTimer.timeout.connect(self.checkIcepapConnection)
 
+
+
     @loggingInfo
     def signalConnections(self):
         self.ui.actionQuit.triggered.connect(self.close)
@@ -278,6 +286,9 @@ class IcepapCMS(QtWidgets.QMainWindow):
             self.contextEditIcepap)""",
             """self.menu.addAction("Delete Icepap system configuration",
             self.btnTreeRemove_on_click)""",
+            """self.menu.addSeparator()""",
+            """self.menu.addAction("Open Icepap console",
+            self.contextOpenConsole)""",
         ]
         self.menu = Qt.QMenu(self)
         font = QtGui.QFont()
@@ -286,23 +297,26 @@ class IcepapCMS(QtWidgets.QMainWindow):
         self.context_menu_item = item
         shown_actions = []
         if item.role == IcepapTreeModel.SYSTEM_OFFLINE:
-            shown_actions = [5, 8, 9, 10]
+            shown_actions = [5, 8, 9, 10, 11, 12]
         if item.role == IcepapTreeModel.DRIVER:
-            shown_actions = [6, 7, 8, 9, 10]
+            shown_actions = [6, 7, 8, 9, 10, 11, 12]
         elif item.role == IcepapTreeModel.DRIVER_CFG:
-            shown_actions = [0, 4, 6, 7, 8, 9, 10]
+            shown_actions = [0, 4, 6, 7, 8, 9, 10, 11, 12]
         elif item.role == IcepapTreeModel.DRIVER_ERROR:
-            shown_actions = [2, 4, 6, 7, 8, 9, 10]
+            shown_actions = [2, 4, 6, 7, 8, 9, 10, 11, 12]
         elif item.role == IcepapTreeModel.DRIVER_WARNING:
-            shown_actions = [1, 4, 6, 7, 8, 9, 10]
+            shown_actions = [1, 4, 6, 7, 8, 9, 10, 11, 12]
         elif item.role == IcepapTreeModel.DRIVER_NEW:
-            shown_actions = [3, 4, 6, 7, 8, 9, 10]
+            shown_actions = [3, 4, 6, 7, 8, 9, 10, 11, 12]
         elif item.role == IcepapTreeModel.SYSTEM or \
                 item.role == IcepapTreeModel.CRATE or \
                 item.role == IcepapTreeModel.SYSTEM_ERROR or \
                 item.role == IcepapTreeModel.SYSTEM_WARNING:
-            shown_actions = [6, 7, 8, 9, 10]
+            shown_actions = [6, 7, 8, 9, 10, 11, 12]
         for i in shown_actions:
+            if self._os_nt and i == 12:
+                # Show console action
+                continue
             exec(actions[i])
         self.menu.popup(self.cursor().pos())
 
@@ -327,6 +341,17 @@ class IcepapCMS(QtWidgets.QMainWindow):
             self.editIcepap(item)
         self.context_menu_item = None
 
+    @loggingInfo
+    def contextOpenConsole(self):
+        if self.context_menu_item:
+            item = self.context_menu_item
+            icepap_system = item.getIcepapSystem()
+            addr = "%s:%s" % (icepap_system.host, icepap_system.port)
+            dlg = IcepapConsole(self, addr)
+            dlg.show()
+        self.context_menu_item = None
+
+
     @loggingInfo
     def contextSolveConflict(self):
         if self.context_menu_item:
@@ -973,7 +998,38 @@ class IcepapCMS(QtWidgets.QMainWindow):
 
     @loggingInfo
     def actionConsoleMth(self):
-        dlg = IcepapConsole(self)
+
+        addr, done = QtWidgets.QInputDialog.getText(
+            self, 'Host connection', 'Please, write a host name to '
+                                     'connect to.')
+        if not done:
+            return
+        if addr.find(":") >= 0:
+            aux = addr.split(':')
+            host = aux[0]
+            port = aux[1]
+        else:
+            host = addr
+            port = "5000"
+
+        if hasattr(self._config, '_options'):
+            ipapcontroller = IcepapsManager()
+            if not ipapcontroller.host_in_same_subnet(host):
+                MessageDialogs.showInformationMessage(
+                    None, "Host connection",
+                    "It is not allowed to connect to {}. "
+                    "(Check subnet)".format(host))
+                return
+        try:
+            IcePAPController(host, int(port))
+        except Exception as e:
+            MessageDialogs.showErrorMessage(None, "Connection error",
+                                            "Error connecting "
+                                            "to " + addr + "\n" + str(e))
+
+            return
+
+        dlg = IcepapConsole(self, addr)
         dlg.show()
 
     @loggingInfo
