@@ -152,6 +152,7 @@ class PageiPapDriver(QtWidgets.QWidget):
 
         self.setLedsOff()
         self.icepap_driver = None
+        self.temp_file = None
         self.inMotion = -1
         self.status = -1
 
@@ -873,7 +874,11 @@ class PageiPapDriver(QtWidgets.QWidget):
                 driver_addr = self.icepap_driver.addr
                 if isinstance(widget, QtWidgets.QDoubleSpinBox) or isinstance(
                         widget, QtWidgets.QSpinBox):
-                    widget.setValue(float(value))
+                    if isinstance(widget, QtWidgets.QDoubleSpinBox):
+                        value = float(value)
+                    else:
+                        value = int(value)
+                    widget.setValue(value)
                     if set_default:
                         widget.defaultvalue = widget.value()
                 elif isinstance(widget, QtWidgets.QCheckBox):
@@ -1164,7 +1169,7 @@ class PageiPapDriver(QtWidgets.QWidget):
     def doImport(self):
         filename = ""
         try:
-            folder = ConfigManager().config["icepap"]["configs_folder"]
+            folder = ConfigManager().configs_folder
             fn = QtWidgets.QFileDialog.getOpenFileName(
                 self, "Open Config File", folder, "*.xml")
             if fn[0] == '':
@@ -1207,7 +1212,7 @@ class PageiPapDriver(QtWidgets.QWidget):
 
     @loggingInfo
     def doExport(self):
-        folder = ConfigManager().config["icepap"]["configs_folder"]
+        folder = ConfigManager().configs_folder
         fn = QtWidgets.QFileDialog.getSaveFileName(
             self, "Save Config File", folder, "*.xml")
         if fn[0] == '':
@@ -1226,6 +1231,9 @@ class PageiPapDriver(QtWidgets.QWidget):
 
     @loggingInfo
     def getXmlData(self):
+        if self.icepap_driver is None:
+            # No system selected!
+            return None
         doc = getDOMImplementation().createDocument(None, "Driver", None)
         dbIcepapSystem = StormManager().getIcepapSystem(
             self.icepap_driver.icepapsystem_name)
@@ -1247,11 +1255,12 @@ class PageiPapDriver(QtWidgets.QWidget):
 
     @loggingInfo
     def doCopy(self):
-        self.temp_file = tempfile.TemporaryFile()
         data = self.getXmlData()
-        self.temp_file.write(data.toprettyxml(encoding="utf-8"))
-        self.temp_file.flush()
-        self.temp_file.seek(0)
+        if data is not None:
+            self.temp_file = tempfile.TemporaryFile()
+            self.temp_file.write(data.toprettyxml(encoding="utf-8"))
+            self.temp_file.flush()
+            self.temp_file.seek(0)
 
     @loggingInfo
     def doPaste(self):
